export const createCommonRender = (tagName, eventNames = []) => function (createElement) {
    const vueElement = this;
    const allListeners = eventNames.reduce((listeners, eventName) => {
        return {
            ...listeners,
            [eventName]: (event) => {
                let emittedValue = event.detail;
                if (event.detail?.value) {
                    emittedValue = event.detail.value;
                }
                vueElement.$emit(eventName, emittedValue);
            },
        };
    }, vueElement.$listeners);
    const attributes = vueElement.$props
        ? Object.keys(vueElement.$props).reduce((attrs, prop) => {
            const attributeName = toDashCase(prop);
            attrs[attributeName] = vueElement.$props[prop];
            return attrs;
        }, {})
        : {};
    return createElement(tagName, {
        ref: "wc",
        domProps: vueElement.$props,
        on: allListeners,
        attrs: { ...attributes, "data-testid": tagName },
    }, [vueElement.$slots.default]);
};
export const createCommonMethod = (methodName) => function (...args) {
    this.$refs.wc[methodName](...args);
};
export const toLowerCase = (str) => str.toLowerCase();
export const toDashCase = (str) => toLowerCase(str
    .replace(/([A-Z0-9])/g, (g) => " " + g[0])
    .trim()
    .replace(/ /g, "-"));
//# sourceMappingURL=utils.js.map